@@ -42,6 +42,7 @@
 #include "pages/eulas/gis-eula-pages.h"
 #include "pages/network/gis-network-page.h"
 #include "pages/timezone/gis-timezone-page.h"
+#include "pages/privacy/gis-privacy-page.h"
 #include "pages/goa/gis-goa-page.h"
 #include "pages/account/gis-account-pages.h"
 #include "pages/password/gis-password-page.h"
@@ -65,6 +66,7 @@ static PageData page_table[] = {
   PAGE (keyboard, FALSE),
   PAGE (eula,     FALSE),
   PAGE (network,  FALSE),
+  PAGE (privacy,  FALSE),
   PAGE (timezone, TRUE),
   PAGE (goa,      FALSE),
   PAGE (account,  TRUE),
